==> pdrx-0.3.4.tar.bz2: pdrx-0.3.4/src/pdr/in_impl_expr.cc <==
// This file is part of the pdr/pdx project.
// Copyright (C) 2010 Torsten Mueller, Bern, Switzerland
//
// This program is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

#include "../libpdrx/common.h"

using namespace std;
using namespace boost;
using namespace boost::posix_time;
using namespace boost::gregorian;
using namespace boost::program_options;

#include "../libpdrx/datatypes.h"
#include "../libpdrx/config.h"
#include "../libpdrx/encoding.h"
#include "db.h"
#include "in_impl.h"

//=== CmdLineExpr ==========================================================
CmdLineExpr::CmdLineExpr ()
	: InputImpl("")
{
}

void CmdLineExpr::Do (const Config& config, Database& database) const throw (Xception)
{
	// get configuration data
	const vector<string>& exprs = config.GetVectorOption("expression"); // get expressions from command line
	if (exprs.empty())
		return;

	bool verbose = config.GetBoolOption("verbose");
	if (verbose)
		cout << (format("evaluating expression%s") % ((exprs.size() == 1) ? "" : "s")).str() << endl;

	Poco::TextEncoding& encoding = GetEncoding(config.GetStringOption("encoding"));

	// in the case of command line expressions we don't want to process
	// expression by expression, we want the whole command line to be
	// processed successfully or not, so we make one single transaction
	// for all

	// build CollectionElements
	Database::CollectionElements elements;
	{
		string msgs;
		const ptime& timestamp = config.GetNow();
		foreach (string expr, exprs)
		{
			try
			{
				trim(expr);
				if (!expr.empty() && expr[0] == '=')
				expr.erase(0, 1);

				if (expr.empty())
					continue;

				Parse(ConvertFrom(expr, encoding), timestamp, verbose, elements);
			}
			catch (const Xception& e)
			{
				if (!msgs.empty())
					msgs += '\n';
				msgs += e.Message();
			}
		}

		if (!msgs.empty())
			throw Xception(msgs);
	}

	// add the contents of all expressions in a single
	// transaction to the database
	database.AddCollectionElements(elements);
}

==> pdrx-1.1.3.tar.bz2: pdrx-1.1.3/src/pdr/in_impl_expr.cc <==
// This file is part of the pdr/pdx project.
// Copyright (C) 2010 Torsten Mueller, Bern, Switzerland
//
// This program is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

#include "../libpdrx/common.h"

using namespace std;
using namespace boost;
using namespace boost::posix_time;
using namespace boost::gregorian;
using namespace boost::program_options;

#include "../libpdrx/datatypes.h"
#include "../libpdrx/config.h"
#include "../libpdrx/encoding.h"
#include "db.h"
#include "in_impl.h"

//=== CmdLineExpr ==========================================================
CmdLineExpr::CmdLineExpr ()
	: InputImpl("")
{
}

void CmdLineExpr::Do (const Config& config, Database& database) const throw (Xception)
{
	// get configuration data
	const vector<string>& exprs = config.GetVectorOption("expression"); // get expressions from command line
	if (exprs.empty())
		return;

	bool verbose = config.GetBoolOption("verbose");
	if (verbose)
		cout << (format("evaluating expression%s") % ((exprs.size() == 1) ? "" : "s")).str() << endl;

	Poco::TextEncoding& encoding = GetEncoding(config.GetStringOption("encoding"));

	// in the case of command line expressions we don't want to process
	// expression by expression, we want the whole command line to be
	// processed successfully or not, so we make one single transaction
	// for all

	// build CollectionsItems
	Database::CollectionsItems items;
	{
		string msgs;
		const ptime& timestamp = config.GetNow();
		foreach (string expr, exprs)
		{
			try
			{
				trim(expr);
				if (!expr.empty() && expr[0] == '=')
				expr.erase(0, 1);

				if (expr.empty())
					continue;

				Parse(ConvertFrom(expr, encoding), timestamp, verbose, items);
			}
			catch (const Xception& e)
			{
				if (!msgs.empty())
					msgs += '\n';
				msgs += e.Message();
			}
		}

		if (!msgs.empty())
			throw Xception(msgs);
	}

	// add the contents of all expressions in a single
	// transaction to the database
	database.AddCollectionsItems(items);
}
